<?php

namespace App\Console;

use App\Models\PathGraphic;
use Illuminate\Console\Scheduling\Schedule;
use Illuminate\Foundation\Console\Kernel as ConsoleKernel;
use Illuminate\Support\Facades\Log;

class Kernel extends ConsoleKernel
{
    /**
     * Define the application's command schedule.
     */
    protected function schedule(Schedule $schedule): void
    {
        $schedule->call(function () {
            Log::info('Running process: ' . date('Y-m-d H:00:00') . ' --- ' . date('Y-m-d H:59:59'));

            $filesToDownload = PathGraphic::with('device')->whereBetween('nextRetry', array(date('Y-m-d H:00:00'), date('Y-m-d H:59:59')))->get();

            foreach ($filesToDownload as $file){
                $device = $file->device;

                if($device->status == 1){

                    $response = Utils::requestFileServer($device->ip, $device->user, $device->password, $file->path, $file->fileName, $file->id,
                        $file->startLine, $file->columns, $file->formatDate, $file->formatTime, $file->separatorr, $file->encoding);

                    if($response['isConnected']){
                        $file->nextRetry = Utils::getNextRetryDate($file);;
                        $file->lastSuccessfulBackup = date('Y-m-d H:i:s');
                        $file->lastUpdate = date('Y-m-d H:i:s');
                        $file->noAttempt = 0;
                    }else{
                        $file->noAttempt = $file->noAttempt + 1;
                        $file->nextRetry = Utils::getNextFailedRetry($file);
                    }
                    $file->save();
                }else {
                    Log::info('The device with ID: ' . $file->id . ' is disabled.');
                }
            }

        })->everyFiveMinutes();
    }

    /**
     * Register the commands for the application.
     */
    protected function commands(): void
    {
        $this->load(__DIR__.'/Commands');

        require base_path('routes/console.php');

    }
}
