<?php

namespace App\Console;

use App\Models\Settings;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\DB;

class Utils
{

    public static function requestPostServer($postData, $url){

        $responseData = '';

        try {

            $settingsObj = Settings::find(1);
            $client = new Client(array('timeout' => 99999999, 'base_uri' => $settingsObj->server . ':' . $settingsObj->port));
            $response = $client->request('POST', '/Teratronix-1.2.0/api' . $url, [
                'form_params' => $postData
            ]);

            // Decode the response
            $result = $response->getBody()->getContents();
            $responseData = $result;

        } catch (\GuzzleHttp\Exception\ServerException $e) {
            $responseData = 1001;
        }

        return $responseData;

    }

    public static function requestPostJsonServer($postData, $url){

        $responseData = '';

        try {
            $settingsObj = Settings::find(1);
            $client = new Client(array('timeout' => 99999999, 'base_uri' => $settingsObj->server . ':' . $settingsObj->port ));
            $response = $client->request('POST', '/Teratronix-1.2.0/api' . $url, [
                'form_params' => $postData
            ]);

            // Decode the response
            $result = $response->getBody()->getContents();
            $responseData = json_decode($result, TRUE);

        } catch (\GuzzleHttp\Exception\ServerException $e) {
            $responseData = 1001;
        }

        return $responseData;

    }

    public static function getNextRetryDate($file){

        $nextRetry = '';
        if($file->periodicity == 1){
            $nextRetry = date( 'Y-m-d ' . $file->time, strtotime( '+24 hours' ));
        } else if($file->periodicity == 2){
            $nextRetry = date( 'Y-m-d ' . $file->time, strtotime( '+7 days' ));
        } else if($file->periodicity == 3){
            $day = date('j');
            if($day >= ($file->vale + 15)){
                $nextDay = $file->value > 9 ? $file->value : '0' . $file->value;
                $nextRetry = date('Y-m-'.$nextDay .' ' . $file->time,strtotime('first day of +1 month'));

            }else{
                $nextDay = $file->value + 15;
                $nextRetry = date('Y-m-'.$nextDay .' ' . $file->time);
            }

        } else{
            $nextDay = $file->value > 9 ? $file->value : '0' . $file->value;
            $nextRetry = date('Y-m-'.$nextDay .' ' . $file->time,strtotime('first day of +1 month'));
        }
        return $nextRetry;
    }

    public static function getNextFailedRetry($file){

        return match ($file->noAttempt) {
            1 => date('Y-m-d H:i:s', strtotime('+5 minutes')),
            2 => date('Y-m-d H:i:s', strtotime('+60 minutes')),
            3 => date('Y-m-d H:i:s', strtotime('+12 hours')),
            default => getNextRetryDate($file),
        };
    }

    public static function requestFileServer($ipAddress, $user, $password, $path, $fileName, $id_file,
                                      $startLine, $columns, $formatDate, $formatTime, $separator, $encoding){

        $postData = array('ipAddress' => $ipAddress, 'user' => $user, 'password' => $password, 'path' => $path ,'fileName' => $fileName, 'id_file' => $id_file,
            'startLine' => $startLine, 'columns' => $columns, 'formatDate' => $formatDate, 'formatTime' => $formatTime, 'separator' => $separator, 'encoding' => $encoding);
        $url = "/recuperarArchivo";
        $response = self::requestPostServer($postData, $url);

        $responseCode = substr($response, 0, 4);

        $isConnected = true;
        $fechasEnArchivo = "";
        $lastUpdate = "";
        $errorCode = 0;

        if($responseCode == "1001" || $responseCode == "1002" || $responseCode == "1003"
            || $responseCode == "1004" || $responseCode == "1005" || $responseCode == "1006" || $responseCode == "1021") {
            $isConnected = false;
            $errorCode = $response;
        }else{


            $postData = array('ipAddress' => $ipAddress, 'fileName' => $fileName, 'id_file' => $id_file,
                'startLine' => $startLine, 'columns' => $columns, 'formatDate' => $formatDate,
                'formatTime' => $formatTime, 'separator' => $separator, 'encoding' => $encoding);
            $url = "/getFileDates";

            $result = self::requestPostServer($postData, $url);

            $dates = explode("|", $result);
            $fechasEnArchivo = array('fechaInicial' => $dates[0], 'fechaFinal' => $dates[1]);


            $lastUpdate = date('Y-m-d H:i:s');
        }

        return  array (
            'success' => true,
            'isConnected' => $isConnected,
            'errorCode' => $errorCode,
            'lastUpdate' => $lastUpdate,
            'fechasArchivo' => $fechasEnArchivo,
            'response' => $response
        );

    }

    public static $DEVICE_TYPE = array('Otro', 'HMI/CSV', 'PLC');

    public static function randomPass($length = 6){
        $chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789jkljaslu78ah387askjh3as5735as43jas8wqas-asdajseyuauys873ah3has457a4s";
        return substr(str_shuffle($chars),0,$length);

    }

    public static function getAccountsBudget($id_provider){

        $accountsbudget = DB::table('ProviderBudget')->join('AccountBudget', 'AccountBudget.id', '=', 'ProviderBudget.id_accountBudget')
            ->join('CostCenterBudget', 'CostCenterBudget.id', '=', 'AccountBudget.id_costCenterBudget')
            ->join('Budget', 'Budget.id', '=', 'CostCenterBudget.id_budget')
            ->select('ProviderBudget.*', 'AccountBudget.name as accountName', 'AccountBudget.accountingAccount as accountAccountingAccount')
            ->where ( "Budget.isActive", "=", 1 )
            ->where ( "ProviderBudget.id_provider", "=", $id_provider )->get();

        return $accountsbudget;
    }


    public static function getAccountsBudgetFromBudget($id_providerBudget){

        $accountsbudget = DB::table('ProviderBudget')->join('AccountBudget', 'AccountBudget.id', '=', 'ProviderBudget.id_accountBudget')
            ->join('CostCenterBudget', 'CostCenterBudget.id', '=', 'AccountBudget.id_costCenterBudget')
            ->join('Budget', 'Budget.id', '=', 'CostCenterBudget.id_budget')
            ->select('ProviderBudget.*', 'AccountBudget.name as accountName', 'AccountBudget.accountingAccount as accountAccountingAccount')
            ->where ( "ProviderBudget.id", "=", $id_providerBudget )->get();

        return $accountsbudget;
    }

    public static function getIdBudgetFromIdProvider($id_providerBudget){

        $budget = DB::table('ProviderBudget')->join('AccountBudget', 'AccountBudget.id', '=', 'ProviderBudget.id_accountBudget')
            ->join('CostCenterBudget', 'CostCenterBudget.id', '=', 'AccountBudget.id_costCenterBudget')
            ->join('Budget', 'Budget.id', '=', 'CostCenterBudget.id_budget')
            ->select('Budget.id')
            ->where ( "ProviderBudget.id", "=", $id_providerBudget )->first();

        return $budget->id;
    }

}
