<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Response;
use Illuminate\Routing\Controller as BaseController;

use App\Models\Bill;
use App\Models\Employee;
use App\Models\Quotation;
use App\Models\Customer;
use App\Models\TaxData;
use App\Models\Product;
use Vsmoraes\Pdf\PdfFacade as PDF;

class BillsController extends BaseController {

	public function getBills() {

		$bills = Bill::where ( "status", "=", 1 )->where( "status", "=", 1 )->with ( 'employee' )->get ();

		return Response::json ( array (
				'success' => true,
				'quotations' => $bills->toArray ()
		) );
	}

	public function getBillDetails(Request $request){

		$id_quotation = $request->input ( "id_quotation" );

		$customers = Customer::where ( 'status', '=', 1 )->with('taxdata')->orderBy('name')->get ();
		$products = Product::where ( "status", "=", 1 )->get ();
		$configurations = Configurations::find(1);

		$quotation = Quotation::with ( 'employee', 'customer.taxdata', 'details', 'states' )->find ( $id_quotation );


		if($quotation->chargeTemplate == 1){
			$quotation->chargeTemplate = true;
		}else{
			$quotation->chargeTemplate = false;
		}

		if($quotation->chargeInternalFreight == 1){
			$quotation->chargeInternalFreight = true;
		}else{
			$quotation->chargeInternalFreight = false;
		}

		if($quotation->chargeExternalFreight == 1){
			$quotation->chargeExternalFreight = true;
		}else{
			$quotation->chargeExternalFreight = false;
		}

		return Response::json ( array (
				'success' => true,
				'bill' => $quotation->toArray(),
				'customers' => $customers->toArray (),
				'products' => $products->toArray (),
				'configurations' => $configurations->toArray(),
		) );
	}


	public function sendEmail(Request $request){

		$id_quotation = $request->input ( 'id_quotation' );
		$emailTo = $request->input ( 'emailTo' );

		$idCot = str_pad ( $id_quotation, 5, "0", STR_PAD_LEFT );

		$html = POController::getHTMLQuotation($id_quotation);
		PDF::load($html)->filename("tmp/$idCot.pdf")->output();

		$dataEmail = array('email' => $emailTo, 'pdfFile' => "tmp/$idCot.pdf");

		Mail::send('emails.quotation', $dataEmail, function ($message) use ($dataEmail) {
			$message->from('sistema@sitma.com.mx', 'Sistema SITMA');
			$message->to($dataEmail['email']);
			$message->subject("Cotización SITMA Industrial");
			$message->attach($dataEmail['pdfFile']);
		});

		return Response::json ( array (
				'success' => true
		));
	}
}

