<?php

namespace App\Http\Controllers;

use App\Models\File;
use App\Models\Settings;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Response;
use Illuminate\Routing\Controller as BaseController;

use App\Models\Customer;
use App\Models\CustomerContact;
use App\Models\CustomerDevice;
use App\Models\Registro;
use App\Models\Variables;
use App\Models\LoginRecord;
use App\Models\Router;
use App\Console\Utils;
use Illuminate\Support\Facades\Redirect;
use App\Models\DownloadFile;

class CustomersController extends BaseController {

	public function getCustomers(){

		$customers = Customer::where("status", "=", 1)->get();

		return Response::json ( array (
				'success' => true,
				'customers' => $customers->toArray()
		) );
	}

	public function getCustomer(Request $request){

		$id_customer = $request->input("id_customer");
		$customer = Customer::with('contacts', 'devices.employee', 'files', 'users', 'devices.paths')->find($id_customer);
		$routers = Router::with('devices.paths')->where('id_customer', '=', $id_customer)->where('status', '=', 1)->get();
		if(count($routers) > 0){
		    foreach ($routers as &$routerTmp){
		        $routerTmp->isEnabled .='';
		    }
		    $routers = $routers->toArray();
		}

		$deviceTypes = Utils::$DEVICE_TYPE;



		return Response::json ( array (
			'success' => true,
			'customer' => $customer->toArray(),
		    'routers' => $routers,
		    'deviceTypes' => $deviceTypes,
            'csrf' => csrf_token()
		) );
	}

	public function saveCustomer(Request $request){

		$customer = $request->input("customer");

		if (isset($customer['id']) && $customer['id'] > 0){
			$customerObj = Customer::find($customer['id']);
		}else{
			$customerObj = new Customer();
		}

        if(isset($customer['expirationDate'])){
            $expirationDate = explode('T', $customer['expirationDate']);
            $customer['expirationDate'] = $expirationDate[0];
        }

		$customerObj->name = $customer['name'];
		$customerObj->company = (isset($customer['company'])) ? $customer['company'] : '';
		$customerObj->address = (isset($customer['address'])) ? $customer['address'] : '';
		$customerObj->address2 = (isset($customer['address2'])) ? $customer['address2'] : '';
		$customerObj->address3 = (isset($customer['address3'])) ? $customer['address3'] : '';
		$customerObj->phone = (isset($customer['phone'])) ? $customer['phone'] : '';
		$customerObj->phone2 = (isset($customer['phone2'])) ? $customer['phone2'] : '';
		$customerObj->phone3 = (isset($customer['phone3'])) ? $customer['phone3'] : '';
		$customerObj->cellphone = (isset($customer['cellphone'])) ? $customer['cellphone'] : '';
		$customerObj->country = (isset($customer['country'])) ? $customer['country'] : '';
		$customerObj->email = (isset($customer['email'])) ? $customer['email'] : '';
		$customerObj->password = (isset($customer['password'])) ? $customer['password'] : '';
		$customerObj->expirationDate = (isset($customer['expirationDate'])) ? $customer['expirationDate'] : '';
        $customerObj->timezone = (isset($customer['timezone'])) ? $customer['timezone'] : 0;
		$customerObj->status = 1;
		$customerObj->save();

		CustomerContact::where('id_customer', '=', $customerObj->id)->delete();

		foreach ($customer['contacts'] as $contact){

			$contactObj = new CustomerContact();
			$contactObj->id_customer = $customerObj->id;
			$contactObj->name = $contact['name'];
			$contactObj->phone = $contact['phone'];
			$contactObj->position = $contact['position'];
			$contactObj->save();

		}

		$customerObj->contacts;

		return Response::json (array (
				'success' => true,
				'customer' => $customerObj->toArray()
		));
	}

	public function deleteCustomer(Request $request){

		$id_customer = $request->input("id_customer");

		Customer::where('id', '=', $id_customer)->update(array('status' => 0));

		return Response::json (array (
				'success' => true
		));

	}


	public function addDevice(Request $request){

		$id_customer = $request->input('id_customer');
		$idDispositivo = $request->input('idDispositivo');
		$user = $request->input('user');

		$deviceObj = new CustomerDevice();
		$deviceObj->idDispositivo = $idDispositivo;
		$deviceObj->id_customer = $id_customer;
		$deviceObj->id_employee = $user['id'];
		$deviceObj->timestamp = date('Y-m-d H:i:s');
		$deviceObj->status = 1;
		$deviceObj->save();

		$devices = CustomerDevice::where('id_customer',  '=', $id_customer)->where('status', '=', 1)->with('employee')->get();

		return Response::json (array (
				'devices' => $devices->toArray(),
				'success' => true
		));
	}

	public function getDeviceDetails(Request $request){

		$id = $request->input('id');
		$id_customer = $request->input('id_customer');

		$device = CustomerDevice::with('variables')->find($id);
		$registers = Registro::where( "status", "=", 1 )->where('idDispositivo', '=', $device->idDispositivo)->get ();
		$devices = CustomerDevice::where('id_customer', '=', $id_customer)->get();

		if($device->type == 1)
		foreach ($registers as $register){

			if(trim($register->coordinates) != ''){
				$coodinates = explode("N", $register->coordinates);

				$register->lat = $coodinates[0];
				$register->long = $coodinates[1];
			}
		}



		return Response::json (array (
				'registers' => $registers->toArray(),
				'devices' => $devices->toArray(),
				'device' => $device->toArray(),
				'success' => true
		));

	}

	public function disableEnableDevice(Request $request){

		$idDispositivo = $request->input('idDispositivo');
		$option = $request->input('option');

		CustomerDevice::where('idDispositivo', '=', $idDispositivo)->update(array('isEnabled' => $option));

		return Response::json (array (
				'success' => true
		));
	}

	public function addVariable(Request $request){

		$variable = $request->input('variable');

		if(isset($variable['id'])){
			$variableObj = Variables::find($variable['id']);
		}else{
			$variableObj = new Variables();
		}

		$variableObj->id_device = $variable['id_device'];
		$variableObj->position = $variable['position'];
		$variableObj->measurement = $variable['measurement'];
		$variableObj->min = $variable['min'];
		$variableObj->max = $variable['max'];
		$variableObj->description = (isset($variable['description']))? $variable['description'] : '';
		$variableObj->status = 1;
		$variableObj->save();

		$variables = Variables::where('id_device', '=', $variable['id_device'])->get();

		return Response::json (array (
				'success' => true,
				'variables' => $variables->toArray()
		));


	}

	public function deleteVariable(Request $request){

		$variable = $request->input('variable');

		Variables::where('id', '=', $variable['id'])->delete();

		$variables = Variables::where('id_device', '=', $variable['id_device'])->get();

		return Response::json (array (
				'success' => true,
				'variables' => $variables->toArray()
		));
	}

	public function getLoginHistoric(Request $request){

        $id_customer = $request->input('id_customer');

		$loginRecords = LoginRecord::with('user', 'customer');
		if($id_customer > 0)
            $loginRecords->where('id_customer', '=', $id_customer);
        $loginRecords = $loginRecords->get();
        if(count($loginRecords) > 0)
		    $loginRecords = $loginRecords->toArray();


        $customers = Customer::where('status', '=', 1)->get();

		return Response::json (array (
			'success' => true,
            'loginRecords' => $loginRecords,
            'customers' => $customers->toArray()
		));

	}

	public function sendEmailSupport(Request $request){

	    $messageToSend = $request->input('messageToSend');
	    $user = $request->input('user');

	    $customer = Customer::find($user['id']);

	    $dataHTML = array('messageToSend' => $messageToSend, 'customer' => $customer->name, 'email' => $customer->email);

        $settingsObj = Settings::find(1);
	    Mail::send('emails.support', $dataHTML, function ($message) use ($settingsObj) {
	        $message->to($settingsObj->emailNotifications);
	        $message->subject("Caso de soporte sistema Tunelrouter");
	    });

	    return Response::json (array (
	       'success' => true
	    ));

	}


	public function activateNotifications(Request $request){

	    $notifications = $request->input('notifications');
	    $user = $request->input('user');


	    $customerObj = Customer::find($user['id']);
	    $customerObj->notifications = $notifications;
	    $customerObj->save();

	    return Response::json (array (
	        'success' => true
	    ));

	}

	public function uploadImageCustomer(Request $request){

	    $id_customer = $request->input("id_customer");
	    $logoFile = $request->file ( 'file' );

	    $fileName = $id_customer . "-" . date('YmdHis') . "." . $logoFile->getClientOriginalExtension();
	    $up1Success = $logoFile->move ( 'logotipos/', $fileName  );
	    $isExito = false;
	    if($up1Success){
	        $isExito = true;

	        $customer = Customer::find($id_customer);
	        $customer->logo = $fileName;
	        $customer->save();
	    }


	    return Response::json (array (
	        'success' => true,
	        'isExito' => $isExito,
	        'fileName' => $fileName
	    ));
	}

    public function uploadImageHome(Request $request){

        $id_customer = $request->input("id_customer");
        $logoFile = $request->file ( 'file' );

        $fileName = $id_customer . "-" . date('YmdHis') . "." . $logoFile->getClientOriginalExtension();
        $up1Success = $logoFile->move ( 'logotipos/', $fileName  );
        $isExito = false;
        if($up1Success){
            $isExito = true;

            $customer = Customer::find($id_customer);
            $customer->homeImg = $fileName;
            $customer->save();
        }


        return Response::json (array (
            'success' => true,
            'isExito' => $isExito,
            'fileName' => $fileName
        ));
    }


	public function uploadFileVPNCustomer(Request $request){

	    $id_customer = $request->input("id_customer");
	    $logoFile = $request->file ( 'file' );

	    $fileName = $id_customer . "-" . date('YmdHis') . "." . $logoFile->getClientOriginalExtension();
        $originalName = $logoFile->getClientOriginalName();

	    $up1Success = $logoFile->move ( 'filesVPN/', $fileName  );
	    $isExito = false;
        $file = '';
	    if($up1Success){
	        $isExito = true;

	        $file = new File();
	        $file->id_customer = $id_customer;
            $file->fileName = $fileName;
            $file->originalName = $originalName;
            $file->status = 1;
            $file->save();
	    }


	    return Response::json (array (
	        'success' => true,
	        'isExito' => $isExito,
	        'fileName' => $fileName,
            'file' => $file
	    ));
	}

	public function deleteFile(Request $request){

        $id_file = $request->input("id_file");

        $fileObj = File::find($id_file);
        $fileObj->status = 0;
        $fileObj->save();

        return Response::json (array (
            'success' => true
        ));

    }

	public function getFile(Request $request){

        header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
        header("Cache-Control: post-check=0, pre-check=0", false);
        header("Pragma: no-cache");

	    $id_file = $request->input('id_file');
	    $type = $request->input('type');

	    if($type > 1){

	        $downloadFile = new DownloadFile();
	        $downloadFile->datetime = date('Y-m-d H:i:s');

	        if($type == 2){
	            $downloadFile->id_customer = $request->input('id_customer');
	        }else if($type == 3){
	            $id_user = $request->input('id_user');
	            $downloadFile->id_user = $id_user;
	        }
	        $downloadFile->save();
	    }

        $fileObj = File::find($id_file);

        return response()->download(public_path() . "/filesVPN/" . $fileObj->fileName, $fileObj->originalName);

	}

	public function getDownloadVPNLog(){

	    $logHistoryc = DownloadFile::with('customer', 'user.customer')->get();

	    if(count($logHistoryc) > 0)
	        $logHistoryc = $logHistoryc->toArray();

	    return Response::json (array (
	        'success' => true,
	        'logsHistoryc' => $logHistoryc
	    ));
	}

	public function removeRouter(Request $request){

	    $id_router = $request->input('id_router');
	    $routerObj = Router::find($id_router);
        $routerObj->status = 0;
        $routerObj->save();

        return Response::json (array (
            'success' => true
        ));

    }

    public function requestSupport(Request $request){

        $message = $request->input('message');

        $dataHTML = array('messageToSend' => $message['messageToSend'], 'email' => $message['email']);

        $settingsObj = Settings::find(1);
        Mail::send('emails.support2', $dataHTML, function ($message) use ($settingsObj){
            $message->to($settingsObj->emailNotifications);
            $message->subject("Caso de soporte sistema Tunelrouter");
        });

        return Response::json (array (
            'success' => true
        ));

    }

}
