<?php
namespace App\Http\Controllers;

use App\Console\Commands\Constants;
use App\Console\Utils;
use App\Http\Requests\Request;
use App\Models\CustomerDevice;
use App\Models\PLCRegister;
use App\Models\Router;
use App\Models\Settings;
use App\Models\User;
use GuzzleHttp\Client;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Response;
use Illuminate\Routing\Controller as BaseController;
use Illuminate\Support\Facades\Hash;


class PLCSController extends BaseController {

    public function getPLCs(\Illuminate\Http\Request $request){

        $id_customer = $request->input('id_customer');

        $user = $request->input('user');

        $devicePLC = CustomerDevice::where('type', '=', 2)->where('id_customer', '=', $id_customer);
        if($user['type'] == 3){
            $userObj = User::find($user['id_user']);
            $registersAvailable = explode(',', $userObj->forPLCRegisters);
            if(trim($userObj->forPLCRegisters) != '' && count($registersAvailable) > 0)
                $devicePLC = $devicePLC->whereIn('id', $registersAvailable);
        }

        $devicePLC = $devicePLC->get();

        if(count($devicePLC) > 0)
            $devicePLC = $devicePLC->toArray();

        return Response::json ( array (
            'success' => true,
            'plcs' => $devicePLC
        ) );

    }

    public function getPLCRegister(\Illuminate\Http\Request $request){

        $id_customer = $request->input('id_customer');

        $devicePLC = PLCRegister::where('type', '=', 2)->where('id_customer', '=', $id_customer)->get();

        if(count($devicePLC) > 0)
            $devicePLC = $devicePLC->toArray();

        return Response::json ( array (
            'success' => true,
            'plcs' => $devicePLC
        ) );

    }


    public function getPLC(\Illuminate\Http\Request $request){

        $id_device = $request->input('id_plc');

        $devicePLC = CustomerDevice::with('registersplc')->find($id_device);

        if(is_object($devicePLC) > 0)
            $devicePLC = $devicePLC->toArray();

        $settingsObj = Settings::find(1);


        return Response::json ( array (
            'success' => true,
            'plc' => $devicePLC,
            'varType' => Constants::$VAR_TYPE,
            'regType' => Constants::$REG_TYPE,
            'urlServer' => $settingsObj->server . ':' . $settingsObj->port
        ) );

    }

    public function savePLC(\Illuminate\Http\Request $request){
        $plc = $request->input('plc');
        $customerDevice = CustomerDevice::with('registersplc', 'customer')->find($plc['id']);
        $customerDevice->port = $plc['port'];
        $customerDevice->idDispositivo = $plc['idDispositivo'];
        $customerDevice->connectionType = $plc['connectionType'];
        $customerDevice->timeout = $plc['timeout'];
        $customerDevice->idD = $plc['idD'];
        $customerDevice->save();
        $registers = $customerDevice->registersplc;

        $deviceReq = array(
            'puerto' => $customerDevice->port,
            'tag' => $customerDevice->idDispositivo,
            'connectionType' => $customerDevice->connectionType,
            'timeout' => $customerDevice->timeout,
            'idD' => $customerDevice->idD,
            'id_customer' => $customerDevice->id_customer,
            'ip' => $customerDevice->ip,
            'id_device' => $customerDevice->id,
            'phone' => $customerDevice->customer->phone,
            'onEvent' => 0,
            'registers' => []
        );


        $isOnAlert = 0;
        foreach ($registers as $register){

            foreach ($plc['registersplc'] as $registerPLC){
                if($register->register == $registerPLC['register']){
                    $register->lastUpdate = isset($registerPLC['lastUpdate'])? $registerPLC['lastUpdate'] : null;
                    $register->errorCode = isset($registerPLC['errorCode']) ? $registerPLC['errorCode'] : null;
                    $register->lastError = isset($registerPLC['lastError'])? $registerPLC['lastError'] : null;
                    $register->save();
                    break;
                }
            }

            if($register->ranges == 1)
                $isOnAlert = 1;



            $deviceReq['registers'][] =
            array(
                'varType' => $register->varType,
                'typeReg' => $register->regType,
                'register' => $register->register,
                'id_registerplc' => $register->id,
                'onEvent' => $register->ranges,
                'gain' => $register->gain,
                'gainValue' => $register->gainValue,
                'offset' => $register->offset,
                'offsetValue' => $register->offsetValue,
                'decimals' => $register->decimals,
                'noDecimals' => $register->noDecimals,
                'lowerRank' => $register->initRange,
                'topRank' => $register->endRange,
                'compareType' => $register->evalType,
            );

        }

        $deviceReq['onEvent'] = $isOnAlert;

        //$requestArr = array('reqDevice' => $deviceReq);
        $response = $this->requestPostJsonServer($deviceReq, '/saveDevice');

        return Response::json ( array (
            'success' => true,
            'response' => $response,
            'deviceReq' => $deviceReq
        ) );

    }

    public function saveRegister(\Illuminate\Http\Request $request){

        $register = $request->input('register');

        if(isset($register['id'])){
            $registerObj = PLCRegister::find($register['id']);
        }else{
            $registerObj = new PLCRegister();
            $registerObj->creationDate = date('Y-m-d H:i:s');
            $registerObj->id_device = $register['id_device'];
        }

        $registerObj->register = isset($register['register']) ? $register['register'] : '';
        $registerObj->varType = isset($register['varType']) ? $register['varType'] : '';
        $registerObj->regType = isset($register['regType']) ? $register['regType'] : '';

        $registerObj->offset = isset($register['offset']) ? $register['offset'] : '';
        $registerObj->offsetValue = isset($register['offsetValue']) ? $register['offsetValue'] : '';
        $registerObj->gainValue = isset($register['gainValue']) ? $register['gainValue'] : '';
        $registerObj->gain = isset($register['gain']) ? $register['gain'] : '';
        $registerObj->decimals = isset($register['decimals']) ? $register['decimals'] : '';
        $registerObj->noDecimals = isset($register['noDecimals']) ? $register['noDecimals'] : '';
        $registerObj->ranges = isset($register['ranges']) ? $register['ranges'] : '';
        $registerObj->evalType = isset($register['evalType']) ? $register['evalType'] : '0';
        $registerObj->initRange = isset($register['initRange']) ? $register['initRange'] : '';
        $registerObj->endRange = isset($register['endRange']) ? $register['endRange'] : '';
        $registerObj->label = isset($register['label']) ? $register['label'] : '';
        $registerObj->passwordCheck = isset($register['passwordCheck']) ? $register['passwordCheck'] : '';
        $registerObj->password = isset($register['password']) ? $register['password'] : '';
        $registerObj->save();

        return Response::json ( array (
            'success' => true,
            'register' => $registerObj->toArray()
        ) );

    }

    public function requestPostServer($postData, $url){

        $responseData = '';

        try {

            $settingsObj = Settings::find(1);
            $client = new Client(array('timeout' => 99999999, 'base_uri' => $settingsObj->server . ':' . $settingsObj->port));
            $response = $client->request('POST', '/Teratronix-1.2.0/api' . $url, [
                'form_params' => $postData
            ]);

            // Decode the response
            $result = $response->getBody()->getContents();
            $responseData = $result;

        } catch (\GuzzleHttp\Exception\ServerException $e) {
            $responseData = 1001;
        }

        return $responseData;

    }

    public function requestPostJsonServer($postData, $url){

        $responseData = '';

        try {
            $settingsObj = Settings::find(1);
            $client = new Client(array('timeout' => 99999999, 'base_uri' => $settingsObj->server . ':' . $settingsObj->port ));
            $response = $client->request('POST', '/Teratronix-1.2.0/api' . $url, [
                'json' => $postData
            ]);

            // Decode the response
            $result = $response->getBody()->getContents();
            $responseData = json_decode($result, TRUE);

        } catch (\GuzzleHttp\Exception\ServerException $e) {
            $responseData = 1001;
        }

        return $responseData;

    }

    public function getLiveData(\Illuminate\Http\Request $request){

        $id_device = $request->input('id_device');

        $arrayReq = array('id_device' => $id_device, 'liveData' => true);

        $deviceData = $this->requestPostJsonServer($arrayReq, '/getDevice');

        $registersObj = PLCRegister::where('id_device', '=', $id_device)->get();
        $deviceDataFinal = null;
        if(isset($deviceData['device']) && count($deviceData['device']['registers'] > 0)) {
            foreach ($deviceData['device']['registers'] as &$register) {
                foreach ($registersObj as $registerObj) {
                    if ($register['register'] == $registerObj->register) {
                        $registerObj->value = $register['valueReg'];
                        $registerObj->lastUpdate = date('Y-m-d H:i:s');
                        $register['lastUpdate'] = date('Y-m-d H:i:s');
                        $registerObj->errorCode = $register['errorCode'];
                        $registerObj->lastError = $register['datetimeError'];
                        $registerObj->save();
                    }
                }
            }
            $deviceDataFinal = $deviceData['device'];
        }


        return Response::json ( array (
            'success' => true,
            'device' => $deviceDataFinal,
            'arrayReq' => $arrayReq
        ) );

    }


    public function setRegisterValue(\Illuminate\Http\Request $request){

        $register = $request->input('register');
        $device = $request->input('device');
        $newValue = $request->input('newValue');

        $arrayReq = array(
            'ipAddress' => $device['ip'],
            'port' => $device['port'],
            'register' => $register['register'],
            'typeReg' => $register['regType'],
            'varType' => $register['varType'],
            'value' => $newValue,
        );

        $callMethod = "/writeTcpRegister";
        if($device['connectionType'] == 2){
            $callMethod = "/writeRTURegister";
            $arrayReq['idDev'] = $device['idD'];
        }

        $deviceData = $this->requestPostServer($arrayReq, $callMethod);

        return Response::json ( array (
            'success' => true,
            'response' => $deviceData
        ) );

    }

    public function deleteRegister(\Illuminate\Http\Request $request){
        $id_register = $request->input('id_register');
        PLCRegister::destroy($id_register);

        return Response::json ( array (
            'success' => true
        ) );
    }

}

