<?php

namespace App\Http\Controllers;

use App\Console\Commands\Constants;
use App\Console\Utils;
use App\Models\CustomerDevice;
use App\Models\PLCRegister;
use App\Models\User;
use App\Models\WorkSheet;
use App\Models\WorkSheetPLCRegister;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Response;
use Illuminate\Routing\Controller as BaseController;

use Illuminate\Support\Facades\DB;

class WorksheetsController extends BaseController {

	public function save(Request $request){

        $worksheet = $request->input('worksheet');

        $isNew = true;
        if(isset($worksheet['id'])){
            $isNew = false;
           $worksheetObj = WorkSheet::find($worksheet['id']);
        }else{

            $worksheetObj = new WorkSheet();
        }

        $worksheetObj->name = $worksheet['name'];
        $worksheetObj->id_customer = $worksheet['id_customer'];
        $worksheetObj->description = isset($worksheet['description']) ? $worksheet['description'] : '';
        $worksheetObj->status = 1;
        $worksheetObj->save();

        $registersToBeDelete = array();
        $registersToBuUpdated = array();
        if(!$isNew)
            $registersToBeDelete = WorkSheetPLCRegister::where('id_workSheet', '=', $worksheetObj->id)->get();

        //Discard existing elements
        $newElements = array();
        $x = 0;
        if(count($worksheet['registers']) > 0)
        foreach ($worksheet['registers'] as $register){
            $currentExisting = false;
            $register['regOrder'] = $x;
            foreach ($registersToBeDelete as $index => $existingRegister){
                if($register['id'] == $existingRegister->id_PLCRegister){
                    $registersToBuUpdated [] = $register;
                    $currentExisting = true;
                    unset($registersToBeDelete[$index]);
                    break;
                }
            }
            if(!$currentExisting)
                $newElements[] = $register;

            $x++;
        }

        //Create new elements
        if(count($newElements) > 0)
        foreach ($newElements as $newElement){
            $newWorkSheetRegister = new WorkSheetPLCRegister();
            $newWorkSheetRegister->id_PLCRegister = $newElement['id'];
            $newWorkSheetRegister->id_workSheet = $worksheetObj->id;
            $newWorkSheetRegister->regOrder = $newElement['regOrder'];
            $newWorkSheetRegister->save();
        }

        //Remove elements
        if(count($registersToBeDelete) > 0)
        foreach ($registersToBeDelete as $elementToRemove){
            DB::table('WorkSheetPLCRegister')
                ->where('id_PLCRegister', '=', $elementToRemove->id_PLCRegister)
                ->where('id_workSheet', '=', $elementToRemove->id_workSheet)
                ->delete();
        }

        //Update registers
        if(count($registersToBuUpdated) > 0)
        foreach ($registersToBuUpdated as $register){
            WorkSheetPLCRegister::where('id_workSheet', '=', $worksheetObj->id)
                ->where('id_PLCRegister', '=', $register['id'])
                ->update(['regOrder' => $register['regOrder']]);
        }

        $worksheetObj = $this::getWorkSheet($worksheetObj->id);

        return Response::json ( array (
            'success' => true,
            'worksheet' => $worksheetObj
        ) );

    }

    public function get(Request $request){
        $id_workSheet = $request->input('id_workSheet');
        $id_customer = $request->input('id_customer');
        $user = $request->input('user');

        $worksheetObj = array('registers' => array());
        if($id_workSheet > 0){
            $worksheetObj = $this::getWorkSheet($id_workSheet);
        }

        $devicesPLC = CustomerDevice::where('type', '=', 2)->where('id_customer', '=', $id_customer);
        if($user['type'] == 3){
            $userObj = User::find($user['id_user']);
            $registersAvailable = explode(',', $userObj->forPLCRegisters);
            if(trim($userObj->forPLCRegisters) != '' && count($registersAvailable) > 0)
                $devicesPLC = $devicesPLC->whereIn('id', $registersAvailable);
        }

        $devicesPLC = $devicesPLC->get();

        if(count($devicesPLC) > 0)
            $devicesPLC = $devicesPLC->toArray();


        return Response::json ( array (
            'success' => true,
            'worksheet' => $worksheetObj,
            'devicesPLC' => $devicesPLC,
            'varType' => Constants::$VAR_TYPE,
            'regType' => Constants::$REG_TYPE
        ) );

    }

    public function gets(Request $request){
        $id_customer = $request->input('id_customer');
        $user = $request->input('user');

        $worksheetsObj = WorkSheet::where('status', '=', 1)->with('registers');

        if($id_customer > 0){
            $worksheetsObj = $worksheetsObj->where('id_customer', '=', $id_customer);
        }

        if($user['type'] == 3){
            $userObj = User::find($user['id_user']);
            $registersAvailable = explode(',', $userObj->forWorkSheetRegisters);
            if(trim($userObj->forWorkSheetRegisters) != '' && count($registersAvailable) > 0)
                $worksheetsObj = $worksheetsObj->whereIn('id', $registersAvailable);
        }

        $worksheetsObj = $worksheetsObj->get();

        foreach ($worksheetsObj as $worksheetObj){
            $worksheetObj->noRegisters = count($worksheetObj->registers);
            unset($worksheetObj->registers);
        }

        return Response::json ( array (
            'success' => true,
            'workSheets' => $worksheetsObj->toArray()
        ) );
    }

    public function delete(Request $request){
        $id_workSheet = $request->input('id_workSheet');

        $worksheetObj = WorkSheet::with('registers')->find($id_workSheet);
        $worksheetObj->status = 0;
        $worksheetObj->save();

        return Response::json ( array (
            'success' => true
        ) );
    }

    public function uploadImage(Request $request)
    {

        $id_workSheet = $request->input('id_workSheet');
        $imageWorkSheet = $request->file('file');

        $worksheetObj = WorkSheet::find($id_workSheet);

        $fileName = $id_workSheet . "-" . date('YmdHis') . "." . $imageWorkSheet->getClientOriginalExtension();
        $up1Success = $imageWorkSheet->move('worksheets/', $fileName);
        if ($up1Success) {
            $worksheetObj->image = $fileName;
            $worksheetObj->save();
        }

        return Response::json(array(
            'success' => true,
            'successFile' => $up1Success,
            'fileName' => $fileName
        ));
    }


    public function getRegisters(Request $request){
        $id_device = $request->input('id_device');

        $registersObj = PLCRegister::where('id_device', '=', $id_device)->get();
        if(count($registersObj) > 0)
            $registersObj = $registersObj->toArray();

        return Response::json ( array (
            'success' => true,
            'registers' => $registersObj
        ) );

    }

    public function getLiveData(Request $request){

        $id_workSheet = $request->input('id_workSheet');

        $worksheetObj = WorkSheet::with('registers.register')->find($id_workSheet);

        $idDevices = array();
        if(count($worksheetObj) > 0)
        foreach ($worksheetObj->registers as $registersObj){
            $idDevices [] = $registersObj->register->id_device;
        }

        $idDevices = array_unique($idDevices);

        $requestJson = array('ids' => implode(',', $idDevices));

        $devicesData = Utils::requestPostServer($requestJson, '/getLiveDevicesData');

        $devicesData = json_decode($devicesData);

        $debugRegister = "";

        $updatedRegisters = array();

        if(isset($devicesData->devices) && count($devicesData->devices > 0)) {
            foreach ($devicesData->devices as $device){
                $registersObj = PLCRegister::with('device')->where('id_device', '=', $device->idDevice)->get();
                foreach ($device->registers as &$register) {
                    foreach ($registersObj as $registerObj) {

                        if ($register->register == $registerObj->register) {
                            $registerObj->value = $register->valueReg;
                            $registerObj->lastUpdate = date('Y-m-d H:i:s');
                            $registerObj->errorCode = $register->errorCode;
                            $registerObj->lastError = $register->datetimeError;
                            $registerObj->save();

                            $updatedRegisters [] = $registerObj->toArray();

                            break;
                        }
                    }
                }
            }
        }



        $worksheetObj = $this->getWorkSheet($worksheetObj->id);
        foreach ($worksheetObj['registers']  as &$register){
            foreach ($updatedRegisters as $updatedRegister){
                if($register['register'] == $updatedRegister['register']
                    && $updatedRegister['device']['id'] == $register['device']['id']){

                    //echo "registro: " . $register['register'] . " device: " . $updatedRegister['device']['id'] . " <br/> ";
                    $register['value'] = $updatedRegister['value'];
                    $register['lastUpdate'] = $updatedRegister['lastUpdate'];
                }
            }
        }

        return Response::json ( array (
            'success' => true,
            'worksheet' => $worksheetObj,
            'devicesData' => $devicesData,
            'updatedRegisters' => $updatedRegisters
        ) );
    }

    private function getWorkSheet($id_workSheet){

        $worksheetObj = WorkSheet::with('registers.register.device')->find($id_workSheet)->toArray();
        $registersData = array();
        if(count($worksheetObj['registers']) > 0){
            foreach ($worksheetObj['registers'] as $registersObj){
                $registersData [] = $registersObj['register'];
            }
            $worksheetObj['registers'] = $registersData;
        }

        if(empty($worksheetObj['image']))
            $worksheetObj['image'] = "none.png";

        return $worksheetObj;

    }
}
