
//Módulo de empleados detalle

(function() {
	'use strict';

	angular.module('app.forms').controller('CustomerDetailController',
			CustomerDetailController);

	CustomerDetailController.$inject = [ '$scope', '$http', '$state',
			'$stateParams', 'SweetAlert', 'Notify', '$rootScope', 'ngDialog' ];
	function CustomerDetailController($scope, $http, $state, $stateParams,
			SweetAlert, Notify, $rootScope, ngDialog ) {

		var vm = this;
		vm.routes = [];
		vm.dataPayment = {
			comment : ''
		};
		vm.stores = {};
		vm.loadingPayment = "";
		vm.loadingDeleteSpecial = "";
		vm.idDispositivo = "";
		vm.specialProduct = {};
		vm.routers = [];
		vm.deviceTypes = [];
		vm.customer = {
			contacts : [],
			taxdata :{
				city:'',
				country: 'México'

			}
		};
		vm.loading = "whirl double-up";

		activate();

		function activate() {

			var id_customer = $stateParams.id;

			if (id_customer > 0) {

				$http.post('/api/admin/customers/getCustomer', {
					id_customer : id_customer,
					user : $rootScope.user
				}).then(function(res) {
					var response = res['data'];
					if (response['success']) {
						vm.customer = response['customer'];
						vm.routers = response['routers'];
						vm.deviceTypes = response['deviceTypes'];
						vm.csrf = response['csrf'];
						vm.customer.expirationDate = new Date(vm.customer.expirationDate + ' 12:00:00');
					}

					vm.loading = "";
				});

			}else{
				vm.loading = "";
			}

			vm.save = function() {

					if(vm.customerForm.$valid) {

						vm.loading = "whirl double-up";

					$http.post('/api/admin/customers/saveCustomer', {
						customer : vm.customer,
						user : $rootScope.user
					}).then(function(res) {

						vm.loading = "";

						var response = res['data'];
						if (response['success']) {
							SweetAlert.swal({
								title : 'Cliente guardado!',
								type : 'success',
								text : 'El cliente se guardó con éxito!'
							}, function() {
								$state.transitionTo('app.customers');
							});
						}
					});
				}

			};

			vm.addContact = function(){

				var newContact = {
					name: '',
					phone: '',
					position: ''
				};

				vm.customer.contacts.push(newContact);

			};



			vm.removeRouter = function(id, index){

				vm.loading = "whirl double-up";

				$http.post('/api/admin/customers/removeRouter', {
					id_router : id,
					user : $rootScope.user
				}).then(function(res) {

					vm.loading = "";
					var response = res['data'];
					if (response['success']) {
						vm.routers.splice(index, 1);
						Notify.alert('El router se eliminó de forma correcta', {status: 'success'});
					}

				});

			};

			vm.addDevice = function(){

				vm.loading = "whirl double-up";

				$http.post('/api/admin/customers/addDevice', {
					id_customer : vm.customer.id,
					idDispositivo : vm.idDispositivo,
					user : $rootScope.user
				}).then(function(res) {

					vm.loading = "";

					var response = res['data'];
					if (response['success']) {
						vm.customer.devices = response.devices;
					}

				});

			};
			
			vm.updateRouter = function(router){

				vm.loading = "whirl double-up";

				$http.post('/api/admin/routers/updateRouter', {
					user : $rootScope.user,
					router : router
				}).then(function(res) {

					vm.loading = "";

					var response = res['data'];
					if (response['success']) {
						Notify.alert('El router se actualizó de forma correcta', {status: 'success'});
						
					}

				});

			};

			vm.getDeviceMaps = function(device) {
				vm.loading = "whirl double-up";

				if(device.type == 1){
					$state.transitionTo('app.device-details', {
						id : device.id,
						id_customer: vm.customer.id

					});
				}else if(device.type == 2){

					$state.transitionTo('app.device-variables', {
						id : device.id,
						id_customer: vm.customer.id
					});

				}
			};
			
			vm.addRouter = function(){

				ngDialog.openConfirm({
		              template: 'addRouterModal',
		              className: 'ngdialog-theme-default large-ngDialog',
		              controller: 'AddRouterController',
		              data: {id_customer: id_customer}
		            }).then(function (router) {
		            	if(router.id > 0){
		            		vm.routers.push(router);
		            	}
		            	
		            }, function (router) {
		            	if(router.id > 0){
		            		vm.routers.push(router);
		            	}
		            });
				
			};
			
			
			vm.updateDevice = function(device, id_route, index){
				
				ngDialog.openConfirm({
		              template: 'modifyDevice',
		              className: 'ngdialog-theme-default large-ngDialog',
		              controller: 'UpdateDeviceController',
		              data: {device: device, deviceTypes: vm.deviceTypes}
		            }).then(function (device) {
		            	if(device.id > 0){
		            		for(var x = 0; x < vm.routers.length; x++){
		            			if(vm.routers[x].id == id_route){
		            				vm.routers[x].devices[index] = device;
		            				break;
		            			}
		            		}
		            	}
		            	
		            }, function (device) {
		            	if(device.id > 0){
		            		for(var x = 0; x < vm.routers.length; x++){
		            			if(vm.routers[x].id == id_route){
		            				vm.routers[x].devices[index] = device;
		            				break;
		            			}
		            		}
		            	}
		            });
				
			};
			
			vm.getDeviceType = function(type){
				for(var x = 0; x < vm.deviceTypes.length; x++){
					if(type == x){
						return vm.deviceTypes[x];
					}
				}
				
			};
			
			
			vm.uploadVPNFile = function(){
				
				
				var file_data = $('#vpnFile').prop('files')[0];

				if(file_data != undefined) {


					vm.loading = "whirl double-up";

					var form_data = new FormData();
					form_data.append('file', file_data);
					form_data.append('id_customer', id_customer);
					form_data.append('_token', vm.csrf);
					console.log(form_data);
					$.ajax({
						url: '/api/admin/customers/uploadFileVPNCustomer', // point to server-side PHP script
						dataType: 'json',  // what to expect back from the PHP script, if anything
						cache: false,
						contentType: false,
						processData: false,
						data: form_data,
						type: 'post',
						success: function (response) {
							vm.loading = "";

							if (response.success == true && response.isExito == true) {
								vm.customer.files.push(response.file);
								Notify.alert('Se cargó el archivo de forma exitosa.', {status: 'success'});
								$state.transitionTo('app.customer-details', {id: id_customer}, {
									reload: true,
									inherit: false,
									notify: true
								});
							} else {
								Notify.alert('Hubo un error al cargar el archivo.', {status: 'danger'});
							}
						}
					});
				}else{
					Notify.alert('Debe seleccionar un archivo.', {status: 'danger'});
				}
			};

			vm.deleteFile = function(id_file, index){

				vm.loadingFiles = "whirl double-up";

				$http.post('/api/admin/customers/deleteFile', {
					user : $rootScope.user,
					id_file : id_file
				}).then(function(res) {

					vm.loadingFiles = "";

					var response = res['data'];
					if (response['success']) {
						vm.customer.files.splice(index, 1);
						Notify.alert('El se eliminó de forma correcta', {status: 'success'});
					}
				});
			};

			vm.getUser = function(id){
				$state.transitionTo('app.user-details', {id : id});
			};
			
			
		}


	};

})();




(function() {
	'use strict';

	angular.module('app.forms').controller('AddRouterController',
			AddRouterController);

	AddRouterController.$inject = [ '$scope', '$http', '$state',
			'$stateParams', 'SweetAlert', 'Notify', '$rootScope', 'ngDialog' ];
	function AddRouterController($scope, $http, $state, $stateParams,
			SweetAlert, Notify, $rootScope, ngDialog ) {

		$scope.router = {
			name: '',
			minIp: '',
			maxIp: '',
			id_customer: $scope.ngDialogData.id_customer
		};
		
		$scope.addRouter = function(){

			if($scope.router.name.length == 0){
				Notify.alert('Debe ingresar el nombre del dispositivo', {status: 'danger'});
				return;
			}
			
			$scope.loading = "whirl double-up";
			
			$http.post('/api/admin/routers/saveRouter', {
				router : $scope.router,
				user : $rootScope.user
			}).then(function(res) {
				
				var response = res['data'];
				if (response['success']) {
					
					$scope.closeThisDialog(response.router);
					
					SweetAlert.swal({
						title : 'Router guardado!',
						type : 'success',
						text : 'El router se guardó con éxito!'
					}, function() {
					});
				}
				
			});
			
		};


	};

})();


(function() {
	'use strict';

	angular.module('app.forms').controller('UpdateDeviceController',
			UpdateDeviceController);

	UpdateDeviceController.$inject = [ '$scope', '$http', '$state',
			'$stateParams', 'SweetAlert', 'Notify', '$rootScope', 'ngDialog' ];
	function UpdateDeviceController($scope, $http, $state, $stateParams,
			SweetAlert, Notify, $rootScope, ngDialog ) {

		$scope.device = angular.copy($scope.ngDialogData.device);

		if($scope.device == null){
			$scope.device = {
				idDispositivo: '',
				ip: '',
				type: '0',
				user: '',
				password: '',
				label: ''
			};
		}

		$scope.device.type += '';
		$scope.deviceTypes = $scope.ngDialogData.deviceTypes;
		$scope.newPath = {path: '', fileName: ''};
		
		$scope.updateDevice = function(){
			
			if($scope.device.idDispositivo.length == 0){
				Notify.alert('Debe ingresar el nombre del dispositivo', {status: 'danger'});
				return;
			}
			
			$scope.loading = "whirl double-up";
			
			$http.post('/api/admin/devices/saveDevice', {
				device : $scope.device,
				user : $rootScope.user
			}).then(function(res) {

				$scope.loading = "";
				var response = res['data'];
				if (response['success']) {
					Notify.alert('El dispositivo se actualizó de forma correcta', {status: 'success'});
					$scope.closeThisDialog($scope.device);
				}
			});
			
		};

		$scope.doPing = function(){
			$scope.loading = "whirl double-up";

			$http.post('/api/admin/devices/doPing', {
				ipAddress : $scope.device.ip,
				user : $rootScope.user
			}).then(function(res) {

				$scope.loading = "";
				var response = res['data'];
				if (response.success && response.pingResult) {
					Notify.alert('El dispositivo respondió de forma correcta.', {status: 'success'});
				}else{
					Notify.alert('El dispositivo NO responde.', {status: 'warning'});
				}
			});
		};

		$scope.showAddDevice = function(){
			$scope.newPath = {path: '', fileName: ''};
			$( "#addPath" ).toggle();
		};

		$scope.hideAddDevice = function(){
			$( "#addPath" ).hide();
		};

		$scope.addDevice = function(){
			if ($scope.newPath.fileName.length < 2) {
				Notify.alert('Ingrese un nombre de archivo válido..', {status: 'danger'});
				return;
			}else if ($scope.newPath.startLine.length < 1) {
				Notify.alert('Seleccione un inicio de línea válido.', {status: 'danger'});
				return;
			}else if ($scope.newPath.columns.length < 1) {
				Notify.alert('Seleccione orden de fecha válido', {status: 'danger'});
				return;
			}else if ($scope.newPath.separatorr.length < 1) {
				Notify.alert('Seleccione un separador de datos válido.', {status: 'danger'});
				return;
			}else if ($scope.newPath.formatDate.length < 1) {
				Notify.alert('Seleccione un formato de fecha válido', {status: 'danger'});
				return;
			}else if ($scope.newPath.formatTime.length < 1) {
				Notify.alert('Seleccione un formato de hora válido.', {status: 'danger'});
				return;
			}else if ($scope.newPath.encoding.length < 1) {
				Notify.alert('Seleccione un encoding válido.', {status: 'danger'});
				return;
			}

			$scope.loading = "whirl double-up";
			$scope.newPath.id_customerDevice = $scope.device.id;

			$http.post('/api/admin/devices/savePath', {
				newPath : $scope.newPath,
				user : $rootScope.user
			}).then(function(res) {

				$scope.loading = "";
				let response = res['data'];
				if (response['success']) {
					Notify.alert('El archivo se agregó de forma correcta.', {status: 'success'});
					$scope.device.paths.push(response.newPath);
					$scope.ngDialogData.device.paths.push(response.newPath);
				}
			});
		};

		$scope.editPath = function(element){
			$scope.newPath = element;
			$( "#addPath" ).show();
			$("#modalDiv").animate({
				scrollTop: $("#addFileDiv").offset().top
			}, 1000);
		};

		$scope.deletePath = function(id, index){

			$http.post('/api/admin/devices/deletePath', {
				user : $rootScope.user,
				id_path : id
			}).then(function(res) {

				$scope.loading = "";
				let response = res['data'];
				if (response['success']) {
					Notify.alert('El archivo se eliminó de forma correcta.', {status: 'success'});
					$scope.device.paths.splice(index, 1);
				}
			});


		};




	};

})();