
(function() {
	'use strict';

	angular.module('app.forms').controller('PLCSController',
			PLCSController);

	PLCSController.$inject = [ '$scope', '$http', '$state', '$stateParams',
			'Notify', '$rootScope', 'SweetAlert', 'ngDialog' ];
	function PLCSController($scope, $http, $state, $stateParams, Notify,
			$rootScope, SweetAlert, ngDialog) {

		var vm = this;
		vm.plcs = [];
		vm.customers = [];
		vm.loading = "";
		vm.id_customer = '0';
		activate();

		function activate() {

			if($rootScope.user.type != 1){
				$rootScope.searchPLC.id_customerPLC = $rootScope.user.id;
			}

			vm.getPLCs = function(){

				vm.loading = "whirl double-up";
	
				$http.post('/api/admin/plcs/getPLCs', {
					user : $rootScope.user,
					id_customer: $rootScope.searchPLC.id_customerPLC
				}).then(function(res) {
		
					var response = res['data'];
					if (response['success']) {
						vm.plcs = response['plcs'];
						vm.loading = "";
					}
				});
			};

			vm.deletePLC = function(index, id_plc){

					vm.loading = "whirl double-up";
					$http.post('/api/admin/plcs/deletePLC', {
						user : $rootScope.user,
						id_plc: id_plc
					}).then(function(res) {

						var response = res['data'];
						if (response['success']) {
							vm.loading = "";
							vm.plcs.splice(index, 1);
						}
					});

			};

			
			vm.getPLC = function(id){
				$state.transitionTo('app.plc-details', {id : id});
			};

			vm.getCustomers = function(){

				vm.loading = "whirl double-up";

				$http.post('/api/admin/customers/getCustomers', {
					user : $rootScope.user
				}).then(function(res) {
					var response = res['data'];
					if (response['success']) {
						vm.loading = "";
						vm.customers = response['customers'];
					}
				});
			};

			vm.doPing = function(ip){

				$scope.loading = "whirl double-up";

				$http.post('/api/admin/devices/doPing', {
					ipAddress : ip,
					user : $rootScope.user
				}).then(function(res) {

					$scope.loading = "";
					var response = res['data'];
					if (response.success && response.pingResult) {
						Notify.alert('El dispositivo '+ip+' respondió de forma correcta.', {status: 'success'});
					}else{
						Notify.alert('El dispositivo '+ip+' NO responde.', {status: 'warning'});
					}
				});
			};
			vm.getPLCs();
			vm.getCustomers();
	    }

	};

})();


(function() {
	'use strict';

	angular.module('app.forms').controller('PLCDetailsController',
		PLCDetailsController);

	PLCDetailsController.$inject = [ '$scope', '$http', '$state', '$stateParams',
		'Notify', '$rootScope', 'SweetAlert', 'ngDialog' ];
	function PLCDetailsController($scope, $http, $state, $stateParams, Notify,
							$rootScope, SweetAlert, ngDialog) {

		var vm = this;
		vm.plc = {};
		vm.loading = "";
		vm.id_plc = '0';
		vm.varType = [];
		vm.regType = [];
		vm.requestDataFlag = false;
		vm.currentInterval = '';
		vm.interval = '';
		vm.urlServer = '';
		vm.isInProcess = false;
		activate();

		function activate() {

			vm.id_plc = $stateParams.id;

			vm.getPLC = function(){

				vm.loading = "whirl double-up";

				$http.post('/api/admin/plcs/getPLC', {
					user : $rootScope.user,
					id_plc: vm.id_plc
				}).then(function(res) {

					var response = res['data'];
					if (response['success']) {
						vm.plc = response.plc;
						vm.varType = response.varType;
						vm.regType = response.regType;
						vm.plc.connectionType += '';
						vm.urlServer = response.urlServer;
						vm.applyCalcules();
						vm.loading = "";
					}
				});
			};

			vm.applyCalcules = function (){
				for(let x = 0; x < vm.plc.registersplc.length; x++){
					vm.plc.registersplc[x] = $rootScope.transformValueRegister(vm.plc.registersplc[x]);
				}
			};

			vm.savePLC = function(){

				if(vm.plc.port === ''){
					Notify.alert('El campo de puerto es requerido.', {status: 'danger'});
					$("#port").focus();
					return;
				}

				if(!Number.isInteger(parseInt(vm.plc.port))){
					Notify.alert('El campo de puerto debe ser un número entero.', {status: 'danger'});
					$("#port").focus();
					return;
				}

				if(vm.plc.idDispositivo === ''){
					Notify.alert('El campo de tag es requerido.', {status: 'danger'});
					$("#tag").focus();
					return;
				}

				if( vm.plc.connectionType === '' ){
					Notify.alert('El campo de tipo de conexión es requerido.', {status: 'danger'});
					$("#connectionType").focus();
					return;
				}

				if(vm.plc.timeout === ''){
					Notify.alert('El campo timeout es requerido.', {status: 'danger'});
					$("#timeout").focus();
					return;
				}

				if(vm.plc.port === ''){
					Notify.alert('El campo ID dispositivo es requerido.', {status: 'danger'});
					$("#idD").focus();
					return;
				}

				vm.loading = "whirl double-up";

				$http.post('/api/admin/plcs/savePLC', {
					user : $rootScope.user,
					plc: vm.plc
				}).then(function(res) {

					var response = res['data'];
					vm.loading = "";

					if (response['success']) {

					}
				});
			};


			vm.addRegister = function (register){
				if($rootScope.user.type == 3 && $rootScope.user.permissions['forPLC'][1] == 0){
					return;
				}

				ngDialog.openConfirm({
					template: 'addRegister',
					className: 'ngdialog-theme-default large-ngDialog',
					controller: 'AddRegisterController',
					data: {register: register, varType: vm.varType, regType: vm.regType, id_device: vm.id_plc, device: vm.plc}
				}).then(function (register) {
				}, function (register) {
					if(register.id > 0){
						let isNew = true;
						for(let x = 0; x < vm.plc.registersplc.length; x++){
							if(vm.plc.registersplc[x].id == register.id){
								vm.plc.registersplc[x] = register;
								isNew = false;
								break;
							}
						}
						if(isNew) {
							vm.plc.registersplc.push(register);
						}
						vm.savePLC();
					}
				});
			};

			vm.requestLiveData = function(){
				if(vm.requestDataFlag === true){
					vm.interval = setInterval(vm.getRegisterData, 5000);
				}else{
					clearInterval(vm.interval);
				}
			};

			vm.getRegisterData = function (){

				if(!vm.isInProcess){

					vm.isInProcess = true;

					vm.loading = "whirl double-up";

					$http.post('/api/admin/plcs/getLiveData', {
						user : $rootScope.user,
						id_device: vm.plc.id
					}).then(function(res) {

						var response = res['data'];
						vm.loading = "";
						if (response.success && response.device != null) {

							vm.isInProcess = false;

							let registers = response.device.registers;
							vm.plc.datetimeError = response.device.datetimeError;
							vm.plc.lastError = response.device.lastError;

							for(let x = 0; x < vm.plc.registersplc.length; x++){
								for(let y  = 0; y < response.device.registers.length; y++){
									if(vm.plc.registersplc[x].register == registers[y].register){
										vm.plc.registersplc[x].value = registers[y].valueReg;
										vm.plc.registersplc[x].lastUpdate = registers[y].lastUpdate;
										vm.plc.registersplc[x].errorCode = registers[y].errorCode;
										vm.plc.registersplc[x].lastError = registers[y].datetimeError;
									}
								}
							}

							vm.applyCalcules();
						}else{
							Notify.alert('Ocurrió un error al traer los datos del dispositivo.', {status: 'danger'});
						}
					}, function errorCallback(response) {
						vm.loading = "";
						vm.isInProcess = false;
						Notify.alert('Ocurrió un error', {status: 'danger'});
					});
				}
			};

			vm.deleteRegister = function (index){



				SweetAlert.swal({
					title: 'Eliminar registro?',
					text: 'Esta operación eliminará por completo el registro',
					type: 'warning',
					showCancelButton: true,
					confirmButtonColor: '#DD6B55',
					confirmButtonText: 'Confirmar',
					cancelButtonText: 'No, cancelar',
				}, function(isConfirm){
					if (isConfirm) {

						vm.loading = "whirl double-up";

						$http.post('/api/admin/plcs/deleteRegister', {
							user : $rootScope.user,
							id_register: vm.plc.registersplc[index].id
						}).then(function(res) {
							var response = res['data'];
							vm.loading = "";
							if (response.success) {
								Notify.alert('El registro se ha eliminado correctamente.', {status: 'success'});
								vm.plc.registersplc.splice(index, 1);
							}
						});

					}
				});












			};

			$scope.$on("$destroy", function() {
				vm.savePLC();
				clearInterval(vm.interval);
			});

			vm.doPing = function(ip){
				$scope.loading = "whirl double-up";

				$http.post('/api/admin/devices/doPing', {
					ipAddress : ip,
					user : $rootScope.user
				}).then(function(res) {

					$scope.loading = "";
					var response = res['data'];
					if (response.success && response.pingResult) {
						Notify.alert('El dispositivo '+ip+' respondió de forma correcta.', {status: 'success'});
					}else{
						Notify.alert('El dispositivo '+ip+' NO responde.', {status: 'warning'});
					}
				});
			};


			vm.getPLC();
		}

	};

})();


(function() {
	'use strict';

	angular.module('app.forms').controller('AddRegisterController',
		AddRegisterController);

	AddRegisterController.$inject = [ '$scope', '$http', '$state', '$stateParams',
		'Notify', '$rootScope', 'SweetAlert', 'ngDialog' ];
	function AddRegisterController($scope, $http, $state, $stateParams, Notify,
								  $rootScope, SweetAlert, ngDialog) {
		$scope.mostrarCaja = false;
		$scope.loading = '';
		$scope.currentRegister = angular.copy($scope.ngDialogData.register);
		$scope.isDisabledVarType = false;
		$scope.newValue = '';
		if($scope.currentRegister === undefined){
			$scope.currentRegister = {
				register: '',
				varType: '1',
				regType: '1',
				id_device: $scope.ngDialogData.id_device,
				label: ''
			};
			$scope.isDisabledVarType = true;
		}else{

			$scope.currentRegister.varType += '';
			$scope.currentRegister.regType += '';
			$scope.currentRegister.noDecimals += '';
			$scope.currentRegister.value = '';
			if($scope.currentRegister.regType === '1'){
				$scope.isDisabledVarType = true;
			}
		}

		$scope.changeRegType = function(){
			if($scope.currentRegister.regType === '1'){
				$scope.currentRegister.varType = '1';
				$scope.isDisabledVarType = true;
				$scope.currentRegister.decimals = '0';
				$scope.currentRegister.noDecimals = '0';


			}else{
				$scope.isDisabledVarType = false;
			}
		};

		$scope.changeVarType = function(){
			if($scope.currentRegister.varType != '6'){
				$scope.currentRegister.decimals = '0';
				$scope.currentRegister.noDecimals = '0';
			}
		};


		$scope.saveRegister = function (){

			if($scope.currentRegister.id == undefined)
			for(let x = 0; x < $scope.ngDialogData.device.registersplc.length; x++){
				if($scope.currentRegister.label == $scope.ngDialogData.device.registersplc[x].label){
					Notify.alert('Esta etiqueta '+$scope.currentRegister.label+' ya se ha dado de alta.', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.regType !== '1' && $scope.currentRegister.varType === '1'){
				Notify.alert('Este tipo de registro no puede ser binario.', {status: 'danger'});
				return;
			}

			if($scope.currentRegister.offset === '1'){
				if(isNaN($scope.currentRegister.offsetValue)){
					Notify.alert('Este tipo de registro no puede ser binario.', {status: 'danger'});
					return;
				}
			}
			/*if($scope.currentRegister.initRange > $scope.currentRegister.endRange){
				Notify.alert('El rango inicial no puede ser mayor al final.', {status: 'danger'});
				return;
			}
			 */

			if($scope.currentRegister.varType == '1'){
				let validateBinary = new RegExp(/^[01]+$/);
				if($scope.newValue){
					if(validateBinary.test($scope.newValue) == false){
						Notify.alert('Este tipo de registro solo puede ser binario.', {status: 'danger'});
						return;
					}
				}
			}

			if($scope.currentRegister.varType == '2'){
				if($scope.newValue < 0 || $scope.newValue > 65535 ){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}
				if($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 65535 ){
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.varType == '3'){
				if($scope.newValue < -32768 || $scope.newValue > 32767 ){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}
				if($scope.currentRegister.initRange < -32768 || $scope.currentRegister.endRange > 32767 ){
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.varType == '4') {
				if($scope.newValue < 0 || $scope.newValue > 4294967295 ){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}

				if ($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 4294967295) {
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.varType == '5') {
				if($scope.newValue < -2147483648 || $scope.newValue > 2147483647){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}

				if ($scope.currentRegister.initRange < -2147483648 || $scope.currentRegister.endRange > 2147483647) {
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}
			if($scope.currentRegister.register < 0 || $scope.currentRegister.register > 65535) {
					Notify.alert('Fuera del limite de registro', {status: 'danger'});
					return;
			}

			if($scope.currentRegister.varType == '7') {
				if($scope.newValue < 0 || $scope.newValue > 18446744073709551615){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}
				if ($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 18446744073709551615) {
					Notify.alert('Rango fuera dellimite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			$scope.loading = "whirl double-up";

			$http.post('/api/admin/plcs/saveRegister', {
				user : $rootScope.user,
				register: $scope.currentRegister,
				device: $scope.ngDialogData.device
			}).then(function(res) {
				var response = res['data'];
				if (response['success']) {
					$scope.loading = "";
					$scope.closeThisDialog(response.register);
				}
			});
		};

		$scope.setRegisterValue = function (){

			if($scope.currentRegister.regType !== '1' && $scope.currentRegister.varType === '1'){
				Notify.alert('Este tipo de registro no puede ser binario.', {status: 'danger'});
				return;
			}
			/*if($scope.currentRegister.initRange > $scope.currentRegister.endRange){
				Notify.alert('El rango inicial no puede ser mayor al final.', {status: 'danger'});
				return;
			}
			 */
			if($scope.currentRegister.varType == '1'){
				let validateBinary = new RegExp(/^[01]+$/);
				if($scope.newValue){
					if(validateBinary.test($scope.newValue) == false){
						Notify.alert('Este tipo de registro solo puede ser binario.', {status: 'danger'});
						return;
					}
				}
			}

			if($scope.currentRegister.varType == '2'){
				if($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 65535 ){
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue < 0 || $scope.newValue > 65535 ){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
				Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
				return;
				}
			}

			if($scope.currentRegister.varType == '3'){
				if($scope.newValue < -32768 || $scope.newValue > 32767 ){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}
				if($scope.currentRegister.initRange < -32768 || $scope.currentRegister.endRange > 32767 ){
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.varType == '4'){
				if($scope.newValue < 0 || $scope.newValue > 4294967295 ){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}
				if ($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 4294967295) {
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.varType == '5'){
				if($scope.newValue < -2147483648 || $scope.newValue > 2147483647){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}

				if ($scope.currentRegister.initRange < -2147483648 || $scope.currentRegister.endRange > 2147483647) {
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.varType == '6') {
				let isValid = /^(\d+)$|^[+-]?(\d+\.\d{0,10})$/;
				if (!isValid.test($scope.newValue)) {
					Notify.alert('Limite de decimales excedido', {status: 'danger'});
					return;
				}
			}

			if($scope.currentRegister.varType == '7'){
				if($scope.newValue < 0 || $scope.newValue > 18446744073709551615){
					Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
					return;
				}

				if ($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 18446744073709551615) {
					Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
					return;
				}
				if($scope.newValue.toString().includes(".") == true){
					Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
					return;
				}
			}

			$scope.loading = "whirl double-up";

			$http.post('/api/admin/plcs/setRegisterValue', {
				user : $rootScope.user,
				register: $scope.currentRegister,
				device: $scope.ngDialogData.device,
				newValue: $scope.newValue
			}).then(function(res) {
				var response = res['data'];
				if (response['success']) {
					$scope.loading = "";
					$scope.closeThisDialog(response.register);
				}
			});
		};

		$scope.setPassword = function (){

			if($scope.currentRegister.confirmPassword == $scope.currentRegister.password){
				//contraseña correcta
				$scope.mostrarCaja = true;
				Notify.alert('Contraseña correcta.', {status: 'success'});
				return;

			}else{
				//contraseña invalida
				$scope.mostrarCaja = false;
				Notify.alert('Contraseña incorrecta.', {status: 'danger'});
				return;
			}
		};




		$scope.$on("$destroy", function() {
			console.log("Esto sucede cuando se cierra");
		});


	};

})();
