(function () {
    'use strict';

    angular.module('app.forms').controller('WorkSheetsController',
        WorkSheetsController);

    WorkSheetsController.$inject = ['$scope', '$http', '$state', '$stateParams',
        'Notify', '$rootScope', 'SweetAlert', 'ngDialog'];

    function WorkSheetsController($scope, $http, $state, $stateParams, Notify,
                                  $rootScope, SweetAlert, ngDialog) {

        var vm = this;
        vm.workSheets = [];
        vm.customers = [];
        vm.loading = "";
        vm.id_customer = '0';
        activate();

        function activate() {

            vm.getCustomers = function () {

                vm.loading = "whirl double-up";

                $http.post('/api/admin/customers/getCustomers', {
                    user: $rootScope.user
                }).then(function (res) {
                    let response = res['data'];
                    if (response['success']) {
                        vm.loading = "";
                        vm.customers = response['customers'];
                    }
                });
            };

            vm.getWorkSheets = function () {

                if ($rootScope.searchWorksheet.id_customer === '0')
                    return;

                vm.loading = "whirl double-up";

                $http.post('/api/admin/worksheets/gets', {
                    user: $rootScope.user,
                    id_customer: $rootScope.searchWorksheet.id_customer
                }).then(function (res) {

                    const response = res['data'];
                    if (response['success']) {
                        vm.workSheets = response.workSheets;
                        vm.loading = "";
                    }
                });
            };

            vm.deleteWorkSheet = function (index, id_workSheet) {


                SweetAlert.swal({
                    title: 'Eliminar hojas de trabajo?',
                    text: 'Esta operación eliminará por completo la hoja de trabajo "' + vm.workSheets[index].name + '"',
                    type: 'warning',
                    showCancelButton: true,
                    confirmButtonColor: '#DD6B55',
                    confirmButtonText: 'Confirmar',
                    cancelButtonText: 'No, cancelar',
                }, function (isConfirm) {
                    if (isConfirm) {

                        vm.loading = "whirl double-up";

                        $http.post('/api/admin/worksheets/deleteWorkSheet', {
                            user: $rootScope.user,
                            id_workSheet: id_workSheet
                        }).then(function (res) {
                            const response = res['data'];
                            vm.loading = "";
                            if (response.success) {
                                Notify.alert('La hoja de trabajo se ha eliminado correctamente.', {status: 'success'});
                                vm.workSheets.splice(index, 1);
                            }
                        });

                    }
                });
            };

            vm.createWorkSheet = function () {
                if ($rootScope.searchWorksheet.id_customer === '0') {
                    Notify.alert('Debe seleccionar un cliente...', {status: 'danger'});
                    return;
                }

                $state.transitionTo('app.worksheet-details', {
                    id: 0,
                    id_customer: $rootScope.searchWorksheet.id_customer
                });
            };


            vm.getWorkSheet = function (id) {
                $state.transitionTo('app.worksheet-details', {
                    id: id,
                    id_customer: $rootScope.searchWorksheet.id_customer
                });
            };

            if ($rootScope.user.type == 1) {
                vm.getCustomers();
            } else {
                $rootScope.searchWorksheet.id_customer = $rootScope.user.id;
            }

            vm.getWorkSheets();
        }

    };

})();


(function () {
    'use strict';

    angular.module('app.forms').controller('WorkSheetDetailController',
        WorkSheetDetailController);

    WorkSheetDetailController.$inject = ['$scope', '$http', '$state', '$stateParams',
        'Notify', '$rootScope', 'SweetAlert', 'ngDialog'];

    function WorkSheetDetailController($scope, $http, $state, $stateParams, Notify,
                                       $rootScope, SweetAlert, ngDialog) {

        let vm = this;
        vm.worksheet = {
            name: '',
            description: '',
            id_customer: 0,
            registers: []
        }
        vm.devicesPLC = []
        vm.varType = [];
        vm.regType = [];
        vm.isInProcess = false;
        vm.requestDataFlag = false;
        vm.interval = null;
        vm.loadingData = "";
        vm.isOrdering = false;
        vm.accumulatedData = [];
        vm.chart = undefined;
        vm.currentRegisterIndex = null;

        activate();

        function activate() {

            const id_customer = $stateParams.id_customer;
            const id_workSheet = $stateParams.id;

            vm.save = function () {

                if (vm.worksheet.name == undefined || vm.worksheet.name == '') {
                    Notify.alert('Debe ingresar al menos el nombre de la hoja de trabajo', {status: 'danger'});
                    document.getElementById("name").focus();
                    return;
                }

                vm.loading = "whirl double-up";

                vm.worksheet.id_customer = id_customer;


                $http.post('/api/admin/worksheets/save', {
                    user: $rootScope.user,
                    worksheet: vm.worksheet
                }).then(function (res) {

                    const response = res['data'];
                    if (response['success']) {
                        vm.loading = "";
                        vm.worksheet = response.worksheet;
                        Notify.alert('La hoja de trabajo se ha guardado con éxito', {status: 'success'});
                    }
                });
            }

            vm.get = function () {
                vm.loading = "whirl double-up";
                $http.post('/api/admin/worksheets/get', {
                    user: $rootScope.user,
                    id_workSheet: id_workSheet,
                    id_customer: id_customer
                }).then(function (res) {

                    const response = res['data'];
                    if (response['success']) {
                        vm.loading = "";
                        vm.worksheet = response.worksheet;
                        vm.devicesPLC = response.devicesPLC;
                        vm.varType = response.varType;
                        vm.regType = response.regType;

                        for (let x = 0; x < vm.worksheet.registers.length; x++) {

                            if(vm.worksheet.registers[x] !== null)
                                vm.worksheet.registers[x] =
                                    $rootScope.transformValueRegister(vm.worksheet.registers[x])
                        }
                    }
                });
            }

            vm.addRegister = function () {

                ngDialog.openConfirm({
                    template: 'addRegisterWorkSheet',
                    className: 'ngdialog-theme-default large-ngDialog',
                    data: {devicesPLC: vm.devicesPLC, varType: vm.varType, regType: vm.regType},
                    controller: 'WorkSheetAddRegistersController',
                }).then(function (i) {

                }, function (devices) {
                    if (devices.length > 0)
                        for (let x = 0; x < devices.length; x++) {
                            for (let y = 0; y < devices[x].registers.length; y++) {
                                vm.worksheet.registers.push(devices[x].registers[y])
                            }
                        }
                    console.log(vm.worksheet)
                });

            }

            vm.showRegisterDetails = function (register) {

                ngDialog.openConfirm({
                    template: 'showRegisterDetails',
                    className: 'ngdialog-theme-default large-ngDialog',
                    data: {register: register, varType: vm.varType, regType: vm.regType},
                });

            }

            vm.requestLiveData = function () {
                if (vm.requestDataFlag === true) {
                    $rootScope.intervalWorkSheets = setInterval(vm.getRegisterData, 5000);
                } else {
                    clearInterval($rootScope.intervalWorkSheets);
                }
            };

            vm.getRegisterData = function () {

                if (!vm.isInProcess) {

                    vm.isInProcess = true;

                    vm.loadingData = "whirl double-up";

                    $http.post('/api/admin/worksheets/getLiveData', {
                        user: $rootScope.user,
                        id_workSheet: vm.worksheet.id
                    }).then(function (res) {

                        vm.isInProcess = false;

                        const response = res['data'];
                        vm.loadingData = "";
                        if (response.success && response.worksheet != null) {
                            vm.worksheet = response.worksheet;
                            for (let x = 0; x < vm.worksheet.registers.length; x++) {
                                vm.worksheet.registers[x] =
                                    $rootScope.transformValueRegister(vm.worksheet.registers[x])
                            }

                            vm.accumulateData();

                        } else {
                            Notify.alert('Ocurrió un error al traer los datos del dispositivo.', {status: 'danger'});
                        }
                    }, function errorCallback(response) {
                        vm.loadingData = "";
                        vm.isInProcess = false;
                        Notify.alert('Ocurrió un error', {status: 'danger'});
                    });
                }
            };

            vm.accumulateData = function () {

                for (let x = 0; x < vm.worksheet.registers.length; x++) {
                    const currentRegister = vm.worksheet.registers[x];
                    const printData = {
                        t: new Date(currentRegister.lastUpdate).getTime(),
                        y: currentRegister.value
                    };
                    if (vm.accumulatedData[currentRegister.device.id + "-" + currentRegister.register] === undefined) {
                        vm.accumulatedData[currentRegister.device.id + "-" + currentRegister.register] = [printData];
                    } else {
                        vm.accumulatedData[currentRegister.device.id + "-" + currentRegister.register].push(printData);
                    }
                }
                vm.printChart(null);
            }


            vm.uploadFileWorksheet = function () {

                let file_data = $('#worksheetImage').prop('files')[0];

                if ($rootScope.validateExtention(file_data)) {

                    if(file_data === undefined)
                        return;

                    vm.loading = "whirl double-up";

                    let form_data = new FormData();
                    form_data.append('file', file_data);
                    form_data.append('id_workSheet', id_workSheet);
                    form_data.append("_token", vm.csrf);
                    console.log(form_data);
                    $.ajax({
                        url: '/api/admin/worksheets/uploadImage', // point to server-side PHP script
                        dataType: 'json',  // what to expect back from the PHP script, if anything
                        cache: false,
                        contentType: false,
                        processData: false,
                        data: form_data,
                        type: 'post',
                        success: function (response) {
                            vm.loading = "";

                            if (response.success == true) {
                                Notify.alert('Se actualizó la imagen de forma exitosa.', {status: 'success'});
                                vm.worksheet.image = response.fileName;
                                $state.transitionTo('app.worksheet-details', {
                                    id: id_workSheet,
                                    id_customer: id_customer
                                }, {reload: true, inherit: false, notify: true});
                            } else {
                                Notify.alert('Hubo un error al cargar la imágen.', {status: 'danger'});
                            }
                        }
                    });
                }
            };


            vm.doPing = function (register) {
                register.isLoading = "whirl double-up";

                $http.post('/api/admin/devices/doPing', {
                    ipAddress: register.device.ip,
                    user: $rootScope.user
                }).then(function (res) {

                    register.isLoading = "";
                    let response = res['data'];
                    if (response.success && response.pingResult) {
                        Notify.alert('El dispositivo ' + register.device.ip + ' respondió de forma correcta.', {status: 'success'});
                    } else {
                        Notify.alert('El dispositivo ' + register.device.ip + ' NO responde.', {status: 'warning'});
                    }
                });
            };

            vm.writeRegister = function (register) {

                ngDialog.openConfirm({
                    template: 'writeRegister',
                    className: 'ngdialog-theme-default',
                    data: {register: register},
                    controller: 'WorkSheetSetValueRegistersController',
                });

            };

            vm.deleteRegister = function (index) {
                vm.worksheet.registers.splice(index, 1)
            }

            vm.downloadRegisterData = function (register){

                if(vm.accumulatedData[register.device.id + "-" + register.register] == undefined ||
                    vm.accumulatedData[register.device.id + "-" + register.register].length < 3){
                    Notify.alert('Todavía no hay datos suficientes para descargar', {status: 'warning'});
                    return
                }

                let itemsFormatted = [];
                let itemsNotFormatted = vm.accumulatedData[register.device.id + "-" + register.register];
                itemsNotFormatted.forEach((item) => {
                    let currentDateTime = new Date(item.t);
                    const currentDate = currentDateTime.getFullYear() + '-' +
                    ((currentDateTime.getMonth()+1) < 10 ? '0' + (currentDateTime.getMonth()+1) : (currentDateTime.getMonth()+1)) + '-' +
                        (currentDateTime.getDate() < 10 ? '0' + currentDateTime.getDate() : currentDateTime.getDate());

                    const currentTime = (currentDateTime.getHours() < 10 ? '0' + currentDateTime.getHours() : currentDateTime.getHours()) + ':' +
                        (currentDateTime.getMinutes() < 10 ? '0' + currentDateTime.getMinutes() : currentDateTime.getMinutes()) + ':' +
                        (currentDateTime.getSeconds() < 10 ? '0' + currentDateTime.getSeconds() : currentDateTime.getSeconds());


                    itemsFormatted.push({
                        date: currentDate,
                        time: currentTime,
                        data: item.y,
                    });
                });

                const headers = {
                    date: 'Fecha',
                    time: 'Hora',
                    data: 'Datos'
                };

                const fileName = register.device.idDispositivo + '-' + register.label;

                exportCSVFile(headers, itemsFormatted, fileName);
            }

            vm.printChart = function (index) {

                if(index !== null){
                    vm.currentRegisterIndex = index;
                }

                if(vm.currentRegisterIndex === null)
                    return


                let register = vm.worksheet.registers[vm.currentRegisterIndex];

                if(vm.accumulatedData[register.device.id + "-" + register.register] == undefined ||
                    vm.accumulatedData[register.device.id + "-" + register.register].length < 3){
                    Notify.alert('Todavía no hay datos suficientes para graficar', {status: 'warning'});
                    return
                }

                const dataToPrint = vm.accumulatedData[register.device.id + "-" + register.register];
                const label = register.label + ' - ' + register.device.idDispositivo + " : " + register.register;

                if(vm.chart != undefined){
                    vm.chart.chartTmp.config.data.datasets[0].label = label;
                    vm.chart.chartTmp.config.data.datasets[0].data = dataToPrint;
                    vm.chart.chartTmp.update();
                    return
                }

                let colors = ['#0D9949', '#5B8DFF', '#52FF8F', '#E7FF47', '#FFBC3B', '#FF2E2E', '#668F2B', '#1A2236', '#84407F', '#A9FE17'];

                Chart.defaults.global.responsive = true;
                vm.chart = {cfg: '', ctx: '', chartTmp: ''};
                vm.chart.ctx = document.getElementById('canvas').getContext('2d');
                let color = Chart.helpers.color;
                let datasets = [];

                datasets.push({
                    label: label,
                    backgroundColor: color(colors[0]).alpha(0.5).rgbString(),
                    borderColor: colors[0],
                    data: dataToPrint,
                    type: 'line',
                    pointRadius: 1,
                    fill: false,
                    lineTension: 0,
                    borderWidth: 2
                });


                vm.chart.cfg = {
                    data: {
                        datasets: datasets
                    },
                    options: {
                        responsive: true,
                        animation: {
                            duration: 0
                        },
                        scales: {
                            xAxes: [{
                                type: 'time',
                                distribution: 'series',
                                offset: true,
                                ticks: {
                                    major: {
                                        enabled: true,
                                        fontStyle: 'bold'
                                    },
                                    source: 'data',
                                    autoSkip: true,
                                    autoSkipPadding: 75,
                                    maxRotation: 0,
                                    sampleSize: 100
                                },
                                afterBuildTicks: function (scale, ticks) {
                                    let majorUnit = scale._majorUnit;
                                    let firstTick = ticks[0];
                                    let i, ilen, val, tick, currMajor, lastMajor;

                                    val = moment(ticks[0].value);
                                    if ((majorUnit === 'minute' && val.second() === 0)
                                        || (majorUnit === 'hour' && val.minute() === 0)
                                        || (majorUnit === 'day' && val.hour() === 9)
                                        || (majorUnit === 'month' && val.date() <= 3 && val.isoWeekday() === 1)
                                        || (majorUnit === 'year' && val.month() === 0)) {
                                        firstTick.major = true;
                                    } else {
                                        firstTick.major = false;
                                    }
                                    lastMajor = val.get(majorUnit);

                                    for (i = 1, ilen = ticks.length; i < ilen; i++) {
                                        tick = ticks[i];
                                        val = moment(tick.value);
                                        currMajor = val.get(majorUnit);
                                        tick.major = currMajor !== lastMajor;
                                        lastMajor = currMajor;
                                    }
                                    return ticks;
                                }
                            }],
                            yAxes: [{
                                gridLines: {
                                    drawBorder: false
                                },
                                scaleLabel: {
                                    display: true,
                                    labelString: 'Registro - ' + register.register
                                }
                            }]
                        },
                        tooltips: {
                            intersect: false,
                            mode: 'index',
                            callbacks: {
                                label: function (tooltipItem, myData) {
                                    let label = myData.datasets[tooltipItem.datasetIndex].label || '';
                                    if (label) {
                                        label += ': ';
                                    }
                                    label += parseFloat(tooltipItem.value).toFixed(2);
                                    return label;
                                }
                            }
                        }
                    }
                };

                vm.chart.chartTmp = new Chart(vm.chart.ctx, vm.chart.cfg);

            }

            function convertToCSV(objArray) {
                var array = typeof objArray != 'object' ? JSON.parse(objArray) : objArray;
                var str = '';

                for (var i = 0; i < array.length; i++) {
                    var line = '';
                    for (var index in array[i]) {
                        if (line != '') line += ','

                        line += array[i][index];
                    }

                    str += line + '\r\n';
                }

                return str;
            }

            function exportCSVFile(headers, items, fileTitle) {
                if (headers) {
                    items.unshift(headers);
                }

                // Convert Object to JSON
                var jsonObject = JSON.stringify(items);

                var csv = convertToCSV(jsonObject);

                var exportedFilenmae = fileTitle + '.csv' || 'export.csv';

                var blob = new Blob([csv], { type: 'text/csv;charset=utf-8;' });
                if (navigator.msSaveBlob) { // IE 10+
                    navigator.msSaveBlob(blob, exportedFilenmae);
                } else {
                    var link = document.createElement("a");
                    if (link.download !== undefined) { // feature detection
                        // Browsers that support HTML5 download attribute
                        var url = URL.createObjectURL(blob);
                        link.setAttribute("href", url);
                        link.setAttribute("download", exportedFilenmae);
                        link.style.visibility = 'hidden';
                        document.body.appendChild(link);
                        link.click();
                        document.body.removeChild(link);
                    }
                }
            }

            vm.openImage = function () {
                ngDialog.open({ template: 'openImageDialog', className: 'ngdialog-theme-default auto-ngDialog',
                    data: {workSheet: vm.worksheet} });
            };

            vm.get()
        }

    };

})();


(function () {
    'use strict';

    angular.module('app.forms').controller('WorkSheetAddRegistersController',
        WorkSheetAddRegistersController);

    WorkSheetAddRegistersController.$inject = ['$scope', '$http', '$state', '$stateParams',
        'Notify', '$rootScope', 'SweetAlert', 'ngDialog'];

    function WorkSheetAddRegistersController($scope, $http, $state, $stateParams, Notify,
                                             $rootScope, SweetAlert, ngDialog) {

        $scope.id_device = 0;
        $scope.registers = []
        $scope.selectedItems = []
        $scope.selectedItemsByDevice = []

        $scope.searchRegisters = function () {

            $scope.loading = "whirl double-up";
            $http.post('/api/admin/worksheets/getRegisters', {
                user: $rootScope.user,
                id_device: $scope.id_device
            }).then(function (res) {
                const response = res['data'];
                if (response['success']) {
                    $scope.loading = "";
                    $scope.registers = response.registers;
                }
            });
        }

        $scope.removeElement = function (device, register) {

            if (device.id == $scope.id_device)
                $scope.registers.push(register);

            for (let x = 0; x < $scope.selectedItemsByDevice.length; x++) {
                if ($scope.selectedItemsByDevice[x].id == device.id) {
                    for (let y = 0; y < $scope.selectedItemsByDevice[x].registers.length; y++) {
                        if ($scope.selectedItemsByDevice[x].registers[y].id == register.id) {
                            $scope.selectedItemsByDevice[x].registers.splice(y, 1)
                            break
                        }
                    }
                    if ($scope.selectedItemsByDevice[x].registers.length === 0) {
                        $scope.selectedItemsByDevice.splice(x, 1)
                    }
                }
            }
        }

        $scope.add = function (index) {

            $scope.selectedItems.push($scope.registers[index]);

            for (let x = 0; x < $scope.selectedItemsByDevice.length; x++) {
                if ($scope.selectedItemsByDevice[x].id === $scope.id_device) {
                    $scope.selectedItemsByDevice[x].registers.push($scope.registers[index])
                    $scope.registers.splice(index, 1)
                    return
                }
            }

            $scope.selectedItemsByDevice.push({id: $scope.id_device, registers: [$scope.registers[index]]})

            $scope.registers.splice(index, 1)
        }

        $scope.getDeviceName = function (id) {
            for (let x = 0; x < $scope.ngDialogData.devicesPLC.length; x++) {
                if ($scope.ngDialogData.devicesPLC[x].id == id) {
                    return $scope.ngDialogData.devicesPLC[x].ip + ":" + $scope.ngDialogData.devicesPLC[x].port + " - " + $scope.ngDialogData.devicesPLC[x].idDispositivo
                }
            }
        }

        $scope.save = function () {
            $scope.closeThisDialog($scope.selectedItemsByDevice);
        }
    }

})();


(function () {
    'use strict';

    angular.module('app.forms').controller('WorkSheetSetValueRegistersController',
        WorkSheetSetValueRegistersController);

    WorkSheetSetValueRegistersController.$inject = ['$scope', '$http', '$state', '$stateParams',
        'Notify', '$rootScope', 'SweetAlert', 'ngDialog'];

    function WorkSheetSetValueRegistersController($scope, $http, $state, $stateParams, Notify,
                                                  $rootScope, SweetAlert, ngDialog) {


        $scope.mostrarCaja = false;
        $scope.newValue = "";
        $scope.currentRegister = $scope.ngDialogData.register;

        $scope.setPassword = function () {

            if ($scope.currentRegister.confirmPassword == $scope.currentRegister.password) {
                //contraseña correcta
                $scope.mostrarCaja = true;
                Notify.alert('Contraseña correcta.', {status: 'success'});
                return;

            } else {
                //contraseña invalida
                $scope.mostrarCaja = false;
                Notify.alert('Contraseña incorrecta.', {status: 'danger'});
                return;
            }
        };

        $scope.setRegisterValue = function () {

            if ($scope.currentRegister.regType !== '1' && $scope.currentRegister.varType === '1') {
                Notify.alert('Este tipo de registro no puede ser binario.', {status: 'danger'});
                return;
            }

            if ($scope.currentRegister.varType == '1') {
                let validateBinary = new RegExp(/^[01]+$/);
                if ($scope.newValue) {
                    if (validateBinary.test($scope.newValue) == false) {
                        Notify.alert('Este tipo de registro solo puede ser binario.', {status: 'danger'});
                        return;
                    }
                }
            }

            if ($scope.currentRegister.varType == '2') {
                if ($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 65535) {
                    Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
                    return;
                }
                if ($scope.newValue < 0 || $scope.newValue > 65535) {
                    Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
                    return;
                }
                if ($scope.newValue.toString().includes(".") == true) {
                    Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
                    return;
                }
            }

            if ($scope.currentRegister.varType == '3') {
                if ($scope.newValue < -32768 || $scope.newValue > 32767) {
                    Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
                    return;
                }
                if ($scope.currentRegister.initRange < -32768 || $scope.currentRegister.endRange > 32767) {
                    Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
                    return;
                }
                if ($scope.newValue.toString().includes(".") == true) {
                    Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
                    return;
                }
            }

            if ($scope.currentRegister.varType == '4') {
                if ($scope.newValue < 0 || $scope.newValue > 4294967295) {
                    Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
                    return;
                }
                if ($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 4294967295) {
                    Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
                    return;
                }
                if ($scope.newValue.toString().includes(".") == true) {
                    Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
                    return;
                }
            }

            if ($scope.currentRegister.varType == '5') {
                if ($scope.newValue < -2147483648 || $scope.newValue > 2147483647) {
                    Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
                    return;
                }

                if ($scope.currentRegister.initRange < -2147483648 || $scope.currentRegister.endRange > 2147483647) {
                    Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
                    return;
                }
                if ($scope.newValue.toString().includes(".") == true) {
                    Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
                    return;
                }
            }

            if ($scope.currentRegister.varType == '6') {
                let isValid = /^(\d+)$|^[+-]?(\d+\.\d{0,10})$/;
                if (!isValid.test($scope.newValue)) {
                    Notify.alert('Limite de decimales excedido', {status: 'danger'});
                    return;
                }
            }

            if ($scope.currentRegister.varType == '7') {
                if ($scope.newValue < 0 || $scope.newValue > 18446744073709551615) {
                    Notify.alert('Valor asignado fuera del limite.', {status: 'danger'});
                    return;
                }

                if ($scope.currentRegister.initRange < 0 || $scope.currentRegister.endRange > 18446744073709551615) {
                    Notify.alert('Rango fuera del limite para este registro.', {status: 'danger'});
                    return;
                }
                if ($scope.newValue.toString().includes(".") == true) {
                    Notify.alert('Para este tipo de registro no se permiten decimales..', {status: 'danger'});
                    return;
                }
            }

            $scope.loading = "whirl double-up";

            $http.post('/api/admin/plcs/setRegisterValue', {
                user: $rootScope.user,
                register: $scope.currentRegister,
                device: $scope.currentRegister.device,
                newValue: $scope.newValue
            }).then(function (res) {
                const response = res['data'];
                if (response['success']) {
                    $scope.loading = "";
                    $scope.closeThisDialog(response.register);
                }
            });
        };


    }
})();

